
.. _amrclaw_examples_advection_2d_flagregions:

Two-dimensional advection of a square illustrating flagregions
================================================================

This example illustrates the new capability introduced in v5.7.0 
to expand the ability to specify regions where different levels of
refinement are forced and/or allowed.  See the documentation.

In this example refinement is allowed in a triangular region and 
forced in a trapezoid.

Adapted from `examples/advection_2d_square` and has a square of high
concentration advecting at constant speed with periodic boundary conditions.
